==> qtjambi-datavisualization-6.2.1-sources.jar: io/qt/datavis/QTouch3DInputHandler.java <==
package io.qt.datavis;


/**
 * <p>Basic touch display based input handler</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qtouch3dinputhandler.html">QTouch3DInputHandler</a></p>
 */
public class QTouch3DInputHandler extends io.qt.datavis.Q3DInputHandler
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTouch3DInputHandler.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTouch3DInputHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTouch3DInputHandler() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qtouch3dinputhandler.html#QTouch3DInputHandler">QTouch3DInputHandler::QTouch3DInputHandler(QObject*)</a></p>
     */
    public QTouch3DInputHandler(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTouch3DInputHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#touchEvent">QAbstract3DInputHandler::touchEvent(QTouchEvent*)</a></p>
     */
    @io.qt.QtUninvokable
    public void touchEvent(io.qt.gui.QTouchEvent event){
        touchEvent_native_QTouchEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @io.qt.QtUninvokable
    private native void touchEvent_native_QTouchEvent_ptr(long __this__nativeId, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTouch3DInputHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTouch3DInputHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTouch3DInputHandler instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-datavisualization-6.3.5-sources.jar: io/qt/datavis/QTouch3DInputHandler.java <==
package io.qt.datavis;


/**
 * <p>Basic touch display based input handler</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qtouch3dinputhandler.html">QTouch3DInputHandler</a></p>
 */
public class QTouch3DInputHandler extends io.qt.datavis.Q3DInputHandler
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTouch3DInputHandler.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTouch3DInputHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTouch3DInputHandler() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qtouch3dinputhandler.html#QTouch3DInputHandler">QTouch3DInputHandler::QTouch3DInputHandler(QObject*)</a></p>
     */
    public QTouch3DInputHandler(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTouch3DInputHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#touchEvent">QAbstract3DInputHandler::touchEvent(QTouchEvent*)</a></p>
     */
    @io.qt.QtUninvokable
    public void touchEvent(io.qt.gui.QTouchEvent event){
        touchEvent_native_QTouchEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @io.qt.QtUninvokable
    private native void touchEvent_native_QTouchEvent_ptr(long __this__nativeId, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTouch3DInputHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTouch3DInputHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTouch3DInputHandler instance, QDeclarativeConstructor constructor);
    
}
